<template>
    <v-dialog
        v-model="addnew"
        fullscreen
        transition="dialog-bottom-transition"
        scrollable
      >
        <v-card tile>
          <v-toolbar card dark color="#525252">
            <v-btn icon light @click="checkProcess">
              <v-icon color="#fff">arrow_back</v-icon>
            </v-btn>
            <v-toolbar-title  v-if="address.id_address">{{ type }} Address</v-toolbar-title>
            <v-toolbar-title  v-else>{{ type }} Address</v-toolbar-title>
            <v-spacer></v-spacer>
          </v-toolbar>
          <v-card-text>
            <v-form ref="form" >
              <v-radio-group hint="Address Type" :column=false v-model="address.address_type" class="flex two _radio_group">
                <v-radio
                value="Company"
                label="Company"
                name="address_type"
                >
                Company
                </v-radio>
                <v-radio
                value="Residential"
                label="Residential"
                name="address_type"
                >
                Residential
                </v-radio>
              </v-radio-group>
              <div class="flex two">
                <input type="hidden" v-model="address.id_address">
                <v-text-field
                  :rules="validateRules"
                  label="First Name*"
                  name="firstname"
                  v-model="address.firstname"
                ></v-text-field>
                <v-text-field
                  :rules="validateRules"
                  label="Last Name*"
                  name="lastname"
                  v-model="address.lastname"
                ></v-text-field>
              </div>
              <div class="flex two" v-if="address.address_type == 'Company'">
                <v-text-field
                  :rules="validateRules"
                  label="Company Name*"
                  name="company"
                  v-model="address.company"
                ></v-text-field>
              </div>
              <div class="flex two">
                <v-text-field
                  :rules="validateRules"
                  label="Address Line 1*"
                  name="address1"
                  v-model="address.address1"
                ></v-text-field>
                <v-text-field
                  label="Address Line 2"
                  name="address2"
                  v-model="address.address2"
                ></v-text-field>
              </div>
              <div class="flex two">
                <v-autocomplete
                  v-model="address.id_country"
                  :rules="validateRules"
                  :items="countries"
                  label="Country*"
                  item-text="name"
                  browser-autocomplete="nope"
                  :item-value="getCountryId"
                  return-object
                  @change="setStates"
                  ></v-autocomplete>
                <v-select
                  v-if="$store.state.cart.isMobile && states"
                  :rules="validateRules"
                  :items="states"
                  label="State or Province*"
                  item-text="name"
                  item-value="id_state"
                  v-model="address.id_state"
                ></v-select>
                <v-autocomplete
                  v-model="address.id_state"
                  :rules="validateRules"
                  v-if="states && !$store.state.cart.isMobile"
                  :items="states"
                  label="State or Province*"
                  item-text="name"
                  browser-autocomplete="nope"
                  item-value="id_state"
                  ></v-autocomplete>
              </div>
              <div class="flex two">
                <v-text-field
                  :rules="validateRules"
                  label="City*"
                  name="city"
                  v-model="address.city"
                ></v-text-field>
                <v-text-field
                  :rules="validateRules"
                  label="Zip Code*"
                  name="postcode"
                  type="tel"
                  maxlength="5"
                  v-model="address.postcode"
                ></v-text-field>
              </div>
              <div class="flex two">
                <v-text-field
                  :rules="mobileRules"
                  label="Mobile*"
                  name="phone_mobile"
                  :mask="phone"
                  v-model="address.phone_mobile"
                  type="tel"
                  maxlength="10"
                ></v-text-field>
                <v-text-field
                 :rules="validateRules"
                  label="Address Alias*"
                  name="alias"
                  v-model="address.alias"
                ></v-text-field>
              </div>
              <div
                class="flex two"
                v-if="!address.id_address"
                >
                <v-checkbox
                  v-if="type == 'invoice'"
                  class="pl-10"
                  v-model="address.sameForDelivery"
                  label="Use same address for Delivery Address"
                  >
                </v-checkbox>
              </div>
              <div class="flex two pl-05 mt-15">
                <v-btn
                  @click="saveAddress"
                  large
                  color="secondary"
                  type="button"
                  :loading="saveAddressLoading"
                  name="submit_address"
                >
                  <span v-if="address.id_address">Update Address</span>
                  <span v-else>Save Address</span>
                </v-btn>
              </div>

            </v-form>
          </v-card-text>
        </v-card>
      </v-dialog>
</template>

<script>
import axios from 'axios';
export default {
    props: ['address', 'type', 'addnew', 'address_list'],
    data () {
      return {
        phone: 'phone',
        validateRules: [],
        mobileRules: [
          v => !!v || 'This field is required',
          v => !!v && v.length >= 10 || 'Mobile must be 10 digit number'
        ],
        errorMessages: '',
        notifications: false,
        sound: true,
        saveAddressLoading: false,
        widgets: false,
        countries: [],
        states: [],
        validate: []
      }
    },
    methods: {
      getSelectedCountry: function (countries, cc) {
        for (var country in countries) {
          if (countries[country]['iso_code'] == cc['iso_code']) {
            this.states = countries[country]['states'];
            return countries[country]['id_country'];
          }
        }

        for (var c in countries) {
          if (countries[c]['iso_code'] == 'US') {
            this.states = countries[c]['states'];
            return countries[c]['id_country'];
          }
        }
      },
      setStates: function (obj) {
        if (obj.id_country) {
          var id_country = obj.id_country;
        } else {
          var id_country = obj;
        }
        this.setSelectedStates(this.countries, id_country);
      },
      getCountryId: function (obj) {
        return obj.id_country;
      },
      saveAddress: function () {
        this.validateRules = [
            v => !!v || 'This field is required'
        ];

        if (!this.$refs.form.validate()) {
          return false;
        }

        var addrs = this.address;

        var form_data = new FormData();

        for (var key in addrs) {
            if (key == 'id_country' && addrs[key]['id_country']) {
              addrs[key] = addrs[key]['id_country'];
            }
            form_data.append(key, addrs[key]);
        }

        form_data.append('type', this.type);
        this.saveAddressLoading = true;
        axios.post(this.$store.state.api_domain + '?comp=process&action=saveAddress', form_data, { withCredentials: true})
        .then((res) => {
          if (res.data.status == 'success') {
            this.validateRules = [];
            if (res.data.status == 'success') {
              this.$store.commit('showSnackBar', res.data.message);
            } else {
              this.$store.commit('showSnackBar', 'Address Successfully inserted');
            }
            this.saveAddressLoading = false;
            this.checkProcess();
          }
        });
      },
      checkProcess: function () {
        
        if (this.type == 'edit') {
          this.address_list.edit_address = false;
        }
        
        if (this.type == 'add New') {
          this.address_list.add_address = false;
        }

        if (this.address_list) {
          this.address_list.getAddresses();
        }
      },
      setSelectedStates: function (countries, c) {
        for (var country in countries) {
          if (countries[country]['id_country'] == c) {
            this.states = countries[country]['states'];
          }
        }
      }
    },
    beforeCreate () {
      this.validateRules = [];
    },
    created () {
      axios.get(this.$store.state.api_domain + '?comp=process&action=getCountries')
      .then((res) => {
        this.countries = res.data.countries;
        if (!this.address.id_country) {
          this.address.id_country = this.getSelectedCountry(this.countries, res.data.current_country);
          this.setSelectedStates(res.data.countries, this.address.id_country);
        } else {
          this.setSelectedStates(res.data.countries, this.address.id_country);
        }
      });
    }
}
</script>
